import axios from 'axios'

axios.defaults.baseURL = 'http://localhost:5000'

// To avoid adding the token to every request we make to a service we can
// instead use an interceptor
axios.interceptors.request.use(function (config) {
  // added for when the code is running on a server for serverside rendering
  if (typeof window === 'undefined') {
    return config
  }
  const token = window.localStorage.getItem('token')
  if (token) {
    config.headers.Authorization = `Bearer ${token}`
  }

  return config
})

const appService = {
   getPing() {
    return new Promise((resolve, reject) => {
        axios.get('/ping')
            .then(response => {
                resolve(response.data)
            })
            .catch(error => { reject(error.status)} )
    })
   },
   getAllBooks() {
        return new Promise((resolve, reject) => {
            axios.get('/books')
                .then(response => {
                    resolve(response.data)
                })
                .catch(error => { reject(error.status)} )
        })
   },
   addBook(payload) {
        return new Promise((resolve, reject) => {
            axios.post('/books', payload)
                .then(response => { resolve(response.data)})
                .catch(error => { reject(error.status)} )
        })
   },
   updateBook(book) {
     return new Promise((resolve, reject) => {
       axios.put(`/books/${book.id}`, book)
        .then(response => {
            resolve(response.data)
        })
        .catch(error => {
            console.log(`Error in book update: ${error}`)
            reject(error.status)
        })
     })
   },
   deleteBook(book) {
     return new Promise((resolve, reject) => {
       axios.delete(`/books/${book.id}`)
         .then(response => {
             resolve(response.data)
         })
         .catch(error => {
             console.log(`appService: Error in deleting book: ${error}`)
             reject(error.status)
         })
     })
   },
}

export default appService
